==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/d06/stdafx_8h.js <==
var stdafx_8h =
[
    [ "__STDC_LIMIT_MACROS", "db/d06/stdafx_8h.html#aeb7e7a856ab7a794b05b6b63ef36ea3e", null ],
    [ "assert", "db/d06/stdafx_8h.html#a0041af519e0e7d47c9bcc83760c4669e", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#a573995326d1e4aaffba3dee51d672ead", null ],
    [ "assert_tcompile", "db/d06/stdafx_8h.html#a485e4ac74c5fc7db7d04d54872ed8ebd", null ],
    [ "cpp_lengthof", "db/d06/stdafx_8h.html#a56a3d33b9de4ee438e2abddf5a8e6b57", null ],
    [ "cpp_offsetof", "db/d06/stdafx_8h.html#a5738e5a467a66e11e2e660bb2e2d26a8", null ],
    [ "cpp_sizeof", "db/d06/stdafx_8h.html#a449dec8413d9691510ed328a8729d634", null ],
    [ "endof", "db/d06/stdafx_8h.html#a09b4de629997653e023ed632bbbf05ab", null ],
    [ "fopen", "db/d06/stdafx_8h.html#a0cab141cf85ea20b1dd561d33f954734", null ],
    [ "IGNORE_UNINITIALIZED_WARNING_START", "db/d06/stdafx_8h.html#a2a45136da5809c000ad15dcbd3f881ae", null ],
    [ "IGNORE_UNINITIALIZED_WARNING_STOP", "db/d06/stdafx_8h.html#a34b91ec372309671cce8be3e2b24bafa", null ],
    [ "INT16_MAX", "db/d06/stdafx_8h.html#ac58f2c111cc9989c86db2a7dc4fd84ca", null ],
    [ "INT16_MIN", "db/d06/stdafx_8h.html#ad4e9955955b27624963643eac448118a", null ],
    [ "INT32_MAX", "db/d06/stdafx_8h.html#a181807730d4a375f848ba139813ce04f", null ],
    [ "INT32_MIN", "db/d06/stdafx_8h.html#a688eb21a22db27c2b2bd5836943cdcbe", null ],
    [ "INT64_MAX", "db/d06/stdafx_8h.html#ad0d744f05898e32d01f73f8af3cd2071", null ],
    [ "INT64_MIN", "db/d06/stdafx_8h.html#ab21f12f372f67b8ff0aa3432336ede67", null ],
    [ "INT8_MAX", "db/d06/stdafx_8h.html#aaf7f29f45f1a513b4748a4e5014ddf6a", null ],
    [ "INT8_MIN", "db/d06/stdafx_8h.html#aadcf2a81af243df333b31efa6461ab8e", null ],
    [ "lastof", "db/d06/stdafx_8h.html#a89183245b230573e74cea1b017247b3a", null ],
    [ "lengthof", "db/d06/stdafx_8h.html#ae72e6e2ae552a721f8916813a92f723b", null ],
    [ "M_PI", "db/d06/stdafx_8h.html#ae71449b1cc6e6250b91f539153a7a0d3", null ],
    [ "M_PI_2", "db/d06/stdafx_8h.html#a958e4508ed28ee5cc04249144312c15f", null ],
    [ "MAX_PATH", "db/d06/stdafx_8h.html#ab99ded389af74001a6298fc9e44e74e5", null ],
    [ "MAX_UVALUE", "db/d06/stdafx_8h.html#a7c37ef4c0163dd2623f45f98fce32b89", null ],
    [ "NOT_REACHED", "db/d06/stdafx_8h.html#a6c2edf1e500e498b687567418bf4fef6", null ],
    [ "offsetof", "db/d06/stdafx_8h.html#ad89ebe5fe5ad08c683f0871118ea8e2f", null ],
    [ "OTTD_ASSERT", "db/d06/stdafx_8h.html#a92962a05434e0eb49146f5616b97734c", null ],
    [ "OTTD_PRINTF64", "db/d06/stdafx_8h.html#a12e7deb7001269f37e07565e3e2f853d", null ],
    [ "OTTD_PRINTFHEX64", "db/d06/stdafx_8h.html#a4520b43371ee420ca07ae3e1a29f2bba", null ],
    [ "PACK", "db/d06/stdafx_8h.html#adafe75fadd92aff527e6099a67bae9cb", null ],
    [ "PACK_N", "db/d06/stdafx_8h.html#a823d13cac45dba2b322246bef4abfb6f", null ],
    [ "PATHSEP", "db/d06/stdafx_8h.html#add147d27dd39c3119dfd2d2e7868a66b", null ],
    [ "PATHSEPCHAR", "db/d06/stdafx_8h.html#a9bea5b819ab3f3edc8e1db3dba8cdee4", null ],
    [ "PERSONAL_DIR", "db/d06/stdafx_8h.html#a5e07e33b44cc4210f42f9c2d3e4836e3", null ],
    [ "PRINTF_SIZE", "db/d06/stdafx_8h.html#a2aa68870f80a1c4ce2b556499250937a", null ],
    [ "SIZE_MAX", "db/d06/stdafx_8h.html#a3c75bb398badb69c7577b21486f9963f", null ],
    [ "UINT16_MAX", "db/d06/stdafx_8h.html#a3ea490c9b3617d4479bd80ef93cd5602", null ],
    [ "UINT32_MAX", "db/d06/stdafx_8h.html#ab5eb23180f7cc12b7d6c04a8ec067fdd", null ],
    [ "UINT64_MAX", "db/d06/stdafx_8h.html#a30654b4b67d97c42ca3f9b6052dda916", null ],
    [ "UINT8_MAX", "db/d06/stdafx_8h.html#aeb4e270a084ee26fe73e799861bd0252", null ],
    [ "byte", "db/d06/stdafx_8h.html#a0c8186d9b9b7880309c27230bbb5e69d", null ],
    [ "int16", "db/d06/stdafx_8h.html#a259fa4834387bd68627ddf37bb3ebdb9", null ],
    [ "int32", "db/d06/stdafx_8h.html#a43d43196463bde49cb067f5c20ab8481", null ],
    [ "int64", "db/d06/stdafx_8h.html#a0a83e07c3711cb033e7a116fb04c7d3f", null ],
    [ "int8", "db/d06/stdafx_8h.html#a1b956fe1df85f3c132b21edb4e116458", null ],
    [ "uint", "db/d06/stdafx_8h.html#a91ad9478d81a7aaf2593e8d9c3d06a14", null ],
    [ "uint16", "db/d06/stdafx_8h.html#a05f6b0ae8f6a6e135b0e290c25fe0e4e", null ],
    [ "uint32", "db/d06/stdafx_8h.html#a1134b580f8da4de94ca6b1de4d37975e", null ],
    [ "uint64", "db/d06/stdafx_8h.html#ac6afe794ed283c11fb63426a58188e5e", null ],
    [ "uint8", "db/d06/stdafx_8h.html#adde6aaee8457bee49c2a92621fe22b79", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#a7219ffee62fcdbc5ac8826e91f0dd84b", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#a2debc91eb29d681269670c7e23a0b911", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#acd0f09348f702984c7550aadfa05b3ee", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#a606b7594b07778c851495c6dcf7e080d", null ],
    [ "assert_compile", "db/d06/stdafx_8h.html#a9b74c2339bc04d68f454e996f92ff39c", null ],
    [ "error", "db/d06/stdafx_8h.html#a2fd756ff8cf6bfff702535245490f32a", null ],
    [ "free", "db/d06/stdafx_8h.html#a481910a98f71609607230116326864b3", null ],
    [ "FS2OTTD", "db/d06/stdafx_8h.html#a1845b074ec4dbd0bc6d09638356b67cf", null ],
    [ "OTTD2FS", "db/d06/stdafx_8h.html#a009fa6756ae76c14ff894bfa17dc66ba", null ],
    [ "usererror", "db/d06/stdafx_8h.html#a10cd6b4ec402e4d8f0525e4ecdbae906", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/d06/stdafx_8h.js <==
var stdafx_8h =
[
    [ "__STDC_LIMIT_MACROS", "db/d06/stdafx_8h.html#aeb7e7a856ab7a794b05b6b63ef36ea3e", null ],
    [ "assert_msg", "db/d06/stdafx_8h.html#a7cbb8a467cbf98769110ed1f4c80a4e5", null ],
    [ "cpp_lengthof", "db/d06/stdafx_8h.html#a56a3d33b9de4ee438e2abddf5a8e6b57", null ],
    [ "cpp_offsetof", "db/d06/stdafx_8h.html#a5738e5a467a66e11e2e660bb2e2d26a8", null ],
    [ "cpp_sizeof", "db/d06/stdafx_8h.html#a449dec8413d9691510ed328a8729d634", null ],
    [ "endof", "db/d06/stdafx_8h.html#a09b4de629997653e023ed632bbbf05ab", null ],
    [ "fopen", "db/d06/stdafx_8h.html#a0cab141cf85ea20b1dd561d33f954734", null ],
    [ "IGNORE_UNINITIALIZED_WARNING_START", "db/d06/stdafx_8h.html#a2a45136da5809c000ad15dcbd3f881ae", null ],
    [ "IGNORE_UNINITIALIZED_WARNING_STOP", "db/d06/stdafx_8h.html#a34b91ec372309671cce8be3e2b24bafa", null ],
    [ "INT16_MAX", "db/d06/stdafx_8h.html#ac58f2c111cc9989c86db2a7dc4fd84ca", null ],
    [ "INT16_MIN", "db/d06/stdafx_8h.html#ad4e9955955b27624963643eac448118a", null ],
    [ "INT32_MAX", "db/d06/stdafx_8h.html#a181807730d4a375f848ba139813ce04f", null ],
    [ "INT32_MIN", "db/d06/stdafx_8h.html#a688eb21a22db27c2b2bd5836943cdcbe", null ],
    [ "INT64_MAX", "db/d06/stdafx_8h.html#ad0d744f05898e32d01f73f8af3cd2071", null ],
    [ "INT64_MIN", "db/d06/stdafx_8h.html#ab21f12f372f67b8ff0aa3432336ede67", null ],
    [ "INT8_MAX", "db/d06/stdafx_8h.html#aaf7f29f45f1a513b4748a4e5014ddf6a", null ],
    [ "INT8_MIN", "db/d06/stdafx_8h.html#aadcf2a81af243df333b31efa6461ab8e", null ],
    [ "lastof", "db/d06/stdafx_8h.html#a89183245b230573e74cea1b017247b3a", null ],
    [ "lengthof", "db/d06/stdafx_8h.html#ae72e6e2ae552a721f8916813a92f723b", null ],
    [ "likely", "db/d06/stdafx_8h.html#a217a0bd562b98ae8c2ffce44935351e1", null ],
    [ "M_PI", "db/d06/stdafx_8h.html#ae71449b1cc6e6250b91f539153a7a0d3", null ],
    [ "M_PI_2", "db/d06/stdafx_8h.html#a958e4508ed28ee5cc04249144312c15f", null ],
    [ "MAX_PATH", "db/d06/stdafx_8h.html#ab99ded389af74001a6298fc9e44e74e5", null ],
    [ "MAX_UVALUE", "db/d06/stdafx_8h.html#a7c37ef4c0163dd2623f45f98fce32b89", null ],
    [ "NOT_REACHED", "db/d06/stdafx_8h.html#a6c2edf1e500e498b687567418bf4fef6", null ],
    [ "offsetof", "db/d06/stdafx_8h.html#ad89ebe5fe5ad08c683f0871118ea8e2f", null ],
    [ "OTTD_ASSERT", "db/d06/stdafx_8h.html#a92962a05434e0eb49146f5616b97734c", null ],
    [ "OTTD_PRINTF64", "db/d06/stdafx_8h.html#a12e7deb7001269f37e07565e3e2f853d", null ],
    [ "OTTD_PRINTFHEX64", "db/d06/stdafx_8h.html#a4520b43371ee420ca07ae3e1a29f2bba", null ],
    [ "PACK", "db/d06/stdafx_8h.html#adafe75fadd92aff527e6099a67bae9cb", null ],
    [ "PACK_N", "db/d06/stdafx_8h.html#a823d13cac45dba2b322246bef4abfb6f", null ],
    [ "PATHSEP", "db/d06/stdafx_8h.html#add147d27dd39c3119dfd2d2e7868a66b", null ],
    [ "PATHSEPCHAR", "db/d06/stdafx_8h.html#a9bea5b819ab3f3edc8e1db3dba8cdee4", null ],
    [ "PERSONAL_DIR", "db/d06/stdafx_8h.html#a5e07e33b44cc4210f42f9c2d3e4836e3", null ],
    [ "PRINTF_SIZE", "db/d06/stdafx_8h.html#a2aa68870f80a1c4ce2b556499250937a", null ],
    [ "PRINTF_SIZEX", "db/d06/stdafx_8h.html#ac6f2ecbf34a5163b139457a370ce6e94", null ],
    [ "SIZE_MAX", "db/d06/stdafx_8h.html#a3c75bb398badb69c7577b21486f9963f", null ],
    [ "UINT16_MAX", "db/d06/stdafx_8h.html#a3ea490c9b3617d4479bd80ef93cd5602", null ],
    [ "UINT32_MAX", "db/d06/stdafx_8h.html#ab5eb23180f7cc12b7d6c04a8ec067fdd", null ],
    [ "UINT64_MAX", "db/d06/stdafx_8h.html#a30654b4b67d97c42ca3f9b6052dda916", null ],
    [ "UINT8_MAX", "db/d06/stdafx_8h.html#aeb4e270a084ee26fe73e799861bd0252", null ],
    [ "unlikely", "db/d06/stdafx_8h.html#ac6c45889010c1bd68631771b64f18101", null ],
    [ "byte", "db/d06/stdafx_8h.html#a0c8186d9b9b7880309c27230bbb5e69d", null ],
    [ "int16", "db/d06/stdafx_8h.html#a259fa4834387bd68627ddf37bb3ebdb9", null ],
    [ "int32", "db/d06/stdafx_8h.html#a43d43196463bde49cb067f5c20ab8481", null ],
    [ "int64", "db/d06/stdafx_8h.html#a0a83e07c3711cb033e7a116fb04c7d3f", null ],
    [ "int8", "db/d06/stdafx_8h.html#a1b956fe1df85f3c132b21edb4e116458", null ],
    [ "uint", "db/d06/stdafx_8h.html#a91ad9478d81a7aaf2593e8d9c3d06a14", null ],
    [ "uint16", "db/d06/stdafx_8h.html#a05f6b0ae8f6a6e135b0e290c25fe0e4e", null ],
    [ "uint32", "db/d06/stdafx_8h.html#a1134b580f8da4de94ca6b1de4d37975e", null ],
    [ "uint64", "db/d06/stdafx_8h.html#ac6afe794ed283c11fb63426a58188e5e", null ],
    [ "uint8", "db/d06/stdafx_8h.html#adde6aaee8457bee49c2a92621fe22b79", null ],
    [ "error", "db/d06/stdafx_8h.html#a2fd756ff8cf6bfff702535245490f32a", null ],
    [ "free", "db/d06/stdafx_8h.html#a481910a98f71609607230116326864b3", null ],
    [ "FS2OTTD", "db/d06/stdafx_8h.html#a1845b074ec4dbd0bc6d09638356b67cf", null ],
    [ "OTTD2FS", "db/d06/stdafx_8h.html#a009fa6756ae76c14ff894bfa17dc66ba", null ],
    [ "usererror", "db/d06/stdafx_8h.html#a10cd6b4ec402e4d8f0525e4ecdbae906", null ]
];
